@@ -9,7 +9,7 @@
  * property of Apple Inc. and are protected by Federal copyright
  * law.  Distribution and use rights are outlined in the file "LICENSE.txt"
  * which should have been included with this file.  If this file is
- * file is missing or damaged, see the license at "http://www.cups.org/".
+ * missing or damaged, see the license at "http://www.cups.org/".
  *
  * This file is subject to the Apple OS-Developed Software exception.
  */
@@ -69,6 +69,7 @@ typedef enum ippfind_op_e		/* Operations for expressions */
   IPPFIND_OP_IS_REMOTE,			/* Is a remote service */
   IPPFIND_OP_DOMAIN_REGEX,		/* Domain matches regular expression */
   IPPFIND_OP_NAME_REGEX,		/* Name matches regular expression */
+  IPPFIND_OP_NAME_LITERAL,		/* Name matches literal string */
   IPPFIND_OP_HOST_REGEX,		/* Hostname matches regular expression */
   IPPFIND_OP_PORT_RANGE,		/* Port matches range */
   IPPFIND_OP_PATH_REGEX,		/* Path matches regular expression */
@@ -93,7 +94,7 @@ typedef struct ippfind_expr_s		/* Expression */
 		*child;			/* Child expressions */
   ippfind_op_t	op;			/* Operation code (see above) */
   int		invert;			/* Invert the result */
-  char		*key;			/* TXT record key */
+  char		*name;			/* TXT record key or literal name */
   regex_t	re;			/* Regular expression for matching */
   int		range[2];		/* Port number range */
   int		num_args;		/* Number of arguments for exec */
@@ -274,6 +275,7 @@ main(int  argc,				/* I - Number of command-line args */
     "IS_REMOTE",
     "DOMAIN_REGEX",
     "NAME_REGEX",
+    "NAME_LITERAL",
     "HOST_REGEX",
     "PORT_RANGE",
     "PATH_REGEX",
@@ -419,6 +421,18 @@ main(int  argc,				/* I - Number of command-line args */
                                NULL)) == NULL)
             return (IPPFIND_EXIT_MEMORY);
         }
+        else if (!strcmp(argv[i], "--literal-name"))
+        {
+          i ++;
+          if (i >= argc)
+          {
+            _cupsLangPrintf(stderr, _("ippfind: Missing name after %s."), "--literal-name");
+            show_usage();
+          }
+
+          if ((temp = new_expr(IPPFIND_OP_NAME_LITERAL, invert, argv[i], NULL, NULL)) == NULL)
+            return (IPPFIND_EXIT_MEMORY);
+        }
         else if (!strcmp(argv[i], "--name"))
         {
           i ++;
@@ -724,6 +738,18 @@ main(int  argc,				/* I - Number of command-line args */
                 address_family = AF_INET6;
                 break;
 
+            case 'N' : /* Literal name */
+		i ++;
+		if (i >= argc)
+		{
+		  _cupsLangPrintf(stderr, _("ippfind: Missing name after %s."), "-N");
+		  show_usage();
+		}
+
+		if ((temp = new_expr(IPPFIND_OP_NAME_LITERAL, invert, argv[i], NULL, NULL)) == NULL)
+		  return (IPPFIND_EXIT_MEMORY);
+		break;
+
             case 'P' :
 		i ++;
 		if (i >= argc)
@@ -1173,27 +1199,51 @@ main(int  argc,				/* I - Number of command-line args */
 			*domain;	/* Domain, if any */
 
     strlcpy(buf, search, sizeof(buf));
-    if (buf[0] == '_')
+
+    if (!strncmp(buf, "_http._", 7) || !strncmp(buf, "_https._", 8) || !strncmp(buf, "_ipp._", 6) || !strncmp(buf, "_ipps._", 7))
     {
       regtype = buf;
     }
     else if ((regtype = strstr(buf, "._")) != NULL)
     {
-      name = buf;
-      *regtype++ = '\0';
+      if (strcmp(regtype, "._tcp"))
+      {
+       /*
+        * "something._protocol._tcp" -> search for something with the given
+        * protocol...
+        */
+
+	name = buf;
+	*regtype++ = '\0';
+      }
+      else
+      {
+       /*
+        * "_protocol._tcp" -> search for everything with the given protocol...
+        */
+
+        /* name = NULL; */
+        regtype = buf;
+      }
     }
     else
     {
+     /*
+      * "something" -> search for something with IPP protocol...
+      */
+
       name    = buf;
       regtype = "_ipp._tcp";
     }
 
     for (domain = regtype; *domain; domain ++)
+    {
       if (*domain == '.' && domain[1] != '_')
       {
-        *domain++ = '\0';
-        break;
+	*domain++ = '\0';
+	break;
       }
+    }
 
     if (!*domain)
       domain = NULL;
@@ -1209,6 +1259,9 @@ main(int  argc,				/* I - Number of command-line args */
 
       service = get_service(services, name, regtype, domain);
 
+      if (getenv("IPPFIND_DEBUG"))
+        fprintf(stderr, "Resolving name=\"%s\", regtype=\"%s\", domain=\"%s\"\n", name, regtype, domain);
+
 #ifdef HAVE_DNSSD
       service->ref = dnssd_ref;
       err          = DNSServiceResolve(&(service->ref),
@@ -1234,6 +1287,9 @@ main(int  argc,				/* I - Number of command-line args */
       * Browse for services of the given type...
       */
 
+      if (getenv("IPPFIND_DEBUG"))
+        fprintf(stderr, "Browsing for regtype=\"%s\", domain=\"%s\"\n", regtype, domain);
+
 #ifdef HAVE_DNSSD
       DNSServiceRef	ref;		/* Browse reference */
 
@@ -1264,14 +1320,6 @@ main(int  argc,				/* I - Number of command-line args */
       _cupsLangPrintf(stderr, _("ippfind: Unable to browse or resolve: %s"),
                       dnssd_error_string(err));
 
-      if (name)
-        printf("name=\"%s\"\n", name);
-
-      printf("regtype=\"%s\"\n", regtype);
-
-      if (domain)
-        printf("domain=\"%s\"\n", domain);
-
       return (IPPFIND_EXIT_BONJOUR);
     }
   }
@@ -1784,6 +1832,9 @@ eval_expr(ippfind_srv_t  *service,	/* I - Service */
       case IPPFIND_OP_NAME_REGEX :
           result = !regexec(&(expression->re), service->name, 0, NULL, 0);
           break;
+      case IPPFIND_OP_NAME_LITERAL :
+          result = !_cups_strcasecmp(expression->name, service->name);
+          break;
       case IPPFIND_OP_HOST_REGEX :
           result = !regexec(&(expression->re), service->host, 0, NULL, 0);
           break;
@@ -1795,11 +1846,11 @@ eval_expr(ippfind_srv_t  *service,	/* I - Service */
           result = !regexec(&(expression->re), service->resource, 0, NULL, 0);
           break;
       case IPPFIND_OP_TXT_EXISTS :
-          result = cupsGetOption(expression->key, service->num_txt,
+          result = cupsGetOption(expression->name, service->num_txt,
 				 service->txt) != NULL;
           break;
       case IPPFIND_OP_TXT_REGEX :
-          val = cupsGetOption(expression->key, service->num_txt,
+          val = cupsGetOption(expression->name, service->num_txt,
 			      service->txt);
 	  if (val)
 	    result = !regexec(&(expression->re), val, 0, NULL, 0);
@@ -2427,8 +2478,8 @@ new_expr(ippfind_op_t op,		/* I - Operation */
   temp->op = op;
   temp->invert = invert;
 
-  if (op == IPPFIND_OP_TXT_EXISTS || op == IPPFIND_OP_TXT_REGEX)
-    temp->key = (char *)value;
+  if (op == IPPFIND_OP_TXT_EXISTS || op == IPPFIND_OP_TXT_REGEX || op == IPPFIND_OP_NAME_LITERAL)
+    temp->name = (char *)value;
   else if (op == IPPFIND_OP_PORT_RANGE)
   {
    /*
